@@ -18,10 +18,10 @@ import kfp
 
 def list_gcs(s: str):
     container_op = dsl.ContainerOp(
-        name='list-gcs-buckets',
-        image='google/cloud-sdk',
-        command=['gsutil'],
-        arguments=['ls']
+        name='main-coon',
+        image='eu.gcr.io/second-capsule-253207/adlinear:latest',
+        command=['python'],
+        arguments=['main_coon.py']
     )
     container_op.add_resource_limit("memory", '100M')
     container_op.add_resource_limit("cpu", '.1')
